Vanlege knapper

Grunnleggende knapper | IF

Nedanfor finner du ein kort beskrivelse av kvar knapp/funksjon.

| Feit tekst.
| Kursiv tekst.
| Understreket tekst.
| Gjennomstreket tekst.
| Rett venstremarg.
| Sentrer.
| Rett høgremarg.
| Rette marger.
| Punktliste.
| Nummerliste
| Reduser innrykk.
| Auk innrykk.
| Angre seinaste endring.
| Gjer om seinaste endring.
| Lage/Redigere lenke, lær meir om denne funksjonen i kapittelet Lage/Redigere lenke.
| Ta bort lenker frå markerte lenker.
| Lage/Redigere anker, lær meir om denne funksjonen i kapittelet Lage/Redigere anker.
| Lage/Redigere bilde, lær meir om denne funksjonen i kapittelet Lage/Redigere bilde.
| Rense/Ordne koden. Denne funksjonen tar bort unødvendig formatering. Bør anvendes når man f.eks. kopierer tekst frå Office-program.
| Viser denne hjelp.
| Åpner ein HTML-kodeeditor.
| Lager ein ny tabell (2x2).
| Lager ei rad ovenfor den noverande raden.
| Lager ei rad under den noverande raden.
| Tar bort ei rad.
| Lager ei kolonne før den noverande kolonnen.
| Lager ei kolonne etter den noverande kolonnen.
| Tar bort ei kolonne.
| Lager ei horisontal linje.
| Tar bort formatering frå markert område.
| Lager nedsenket tekst.
| Lager opphøgd tekst.

Gå til: Innhaldsoversikt | Toppen